==> scale-0.2.1.tar.gz: scale-0.2.1/include/scale/alloc.h <==
/*
 * $Id: alloc.h,v 1.7 2004/08/05 13:54:30 jklein Exp $
 * $Author: jklein $
 * $Log: alloc.h,v $
 * Revision 1.7  2004/08/05 13:54:30  jklein
 * Fixed so that Scale can be compiled on Mac OSX(10.3 or higher).
 *
 * Revision 1.6  2004/07/09 09:43:58  jklein
 * few small changes.
 *
 * Revision 1.5  2004/06/28 09:51:09  jklein
 * interface was changed in scale/iterator.h
 *
 * Revision 1.4  2004/06/26 06:58:13  jklein
 * small fix in each header files.
 *
 * Revision 1.3  2004/06/23 12:59:01  jklein
 * Added scale/btree.h, sc_btree.c.
 *
 * Revision 1.2  2004/06/21 16:44:17  jklein
 * Added iterator.
 *
 */

/**
   <p>malloc/calloc/realloc/freeΥåѡåפ줿δؿ
   ؾˡ롣Scale饤֥δˤȤơγݤ˼
   Ȥ˼٤ưϰʲΤɤ餫Ǥȹͤ롣</p>

   <ul>
     <li>ץλ</li>
     <li>Ƽ</li>
   </ul>

   <p>⤷ʤΥץबԤˤȤΤʤСⵤˤ
   s_mallocƤӽФƤɤγݤ˼ԤȤϼưŪexit()
   Ƥ֡ԤˤʤСֲǤץϥɥ
   ؿʰʲꥨ顼ϥɥˤs_merror_handler()˥åȤɬפ
   롣ꥨ顼ϥɥ餬ԤʤʤФʤʤȤϰʲ̤</p>

   <ol>
     <li></li>
     <li>true򡢽ʤfalse֤</li>
   </ol>

   <p>⤷⡢褺false֤ȥץ¸³ԲǽȤơϤ
   exit()ƤФ뤬true֤ХκƼԤʤȤ
   ꥨ顼ϥɥ餬餫Υtrue֤Ƥ⡢ޤ
   ݤ꤬­ʤȤ奨⤢롣Τ褦
   ȤϷ֤ߤ꤬ݤǤޤǡ˥ꥨ顼ϥɥ
   Ƥ³롣</p>

   <p>Scale󶡤ɸˤ̵ؿġҤȤĤϡs_realocn()
   s_freen()ȤäǸ`n'դؿ⤦ҤȤĤs_creallocn()
   s_cfreen()Ȥäǽ`c'դؿԤϡɽεǽȤƤ
   `n'դʤΤƱScaleΥѥMEMORY_DEBUG
   ȥγݡϿ褦ˤʤ롣ˤꡢ
   ˺ʥ꡼ˤ򸫤Ĥ뤳ȤǽˤʤΤǡScale饤֥
   ǤϾ`n'դƤ֡Ԥϡ¸εǽɲäƥ򥯥ꥢ
   롣s_creallocn()ϳĥΰ`Τ'򥯥ꥢȤ
   ꤬ݻǡϾäʤs_cfreen()ϥ򥯥ꥢƤ
   Τǡѥɤ䵡̩Ȥǡפ
   ळȤɤ</p>
*/

#ifndef _SCALE_ALLOC_H_
#define _SCALE_ALLOC_H_

#include "scale/commons.h"

#define typed_malloc(__type) (__type *)s_malloc(sizeof(__type))
#define typed_calloc(__type) (__type *)s_calloc(sizeof(__type))


/** ꡦ顼ϥɥ */
typedef sboolean (*merror_handler)();


/** ꡦ顼ϥɥ򥻥åȤ롣 */
void			s_merror_handler(merror_handler);

/** ݤ */
spointer		s_malloc(size_t);

/** ݤΤ0ǽ롣 */
spointer		s_calloc(size_t, size_t);

/** ĥ롣 */
spointer		s_realloc(spointer p, size_t n);

/** Υꥵꤷơoldn˥ĥ롣 */
spointer		s_reallocn(spointer p, size_t oldn, size_t newn);

/** ưs_reallocnƱ˳ݤ0ǽ롣
	oldn >= newnǤȤs_reallocnȤޤäƱǤ롣*/
spointer		s_creallocn(spointer p, size_t oldn, size_t newn);

/** 롣 */
void			s_free(spointer p);

/** ꥵꤷƲ */
void			s_freen(spointer p, size_t n);

/** s_freen()ƱpΤ0ǽ롣 */
void			s_cfreen(spointer p, size_t n);

/** Scale饤֥ΥѥMEMORY_DEBUGƤС
	߳ݤƤ礭֤
	scale/alloc.hƤϢΥϢؿ
	̤ƵϿΤǡľmallocreallocѤϵϿʤ

	ѥMEMORY_DEBUGƤʤäȤϾ0֤ */
size_t			get_total_memory(void);

#endif /* _SCALE_ALLOC_H_ */

==> scale-0.3.0.tar.gz: scale-0.3.0/include/scale/alloc.h <==
/*
 * $Id: alloc.h,v 1.9 2004/09/04 07:08:01 jklein Exp $
 * $Author: jklein $
 * $Log: alloc.h,v $
 * Revision 1.9  2004/09/04 07:08:01  jklein
 * fixed "const spointer" to "sconstpointer".
 *
 * Revision 1.8  2004/08/08 07:14:45  jklein
 * Added 'resize()' function to array objects.
 *
 * Revision 1.7  2004/08/05 13:54:30  jklein
 * Fixed so that Scale can be compiled on Mac OSX(10.3 or higher).
 *
 * Revision 1.6  2004/07/09 09:43:58  jklein
 * few small changes.
 *
 * Revision 1.5  2004/06/28 09:51:09  jklein
 * interface was changed in scale/iterator.h
 *
 * Revision 1.4  2004/06/26 06:58:13  jklein
 * small fix in each header files.
 *
 * Revision 1.3  2004/06/23 12:59:01  jklein
 * Added scale/btree.h, sc_btree.c.
 *
 * Revision 1.2  2004/06/21 16:44:17  jklein
 * Added iterator.
 *
 */

/**
   <p>malloc/calloc/realloc/freeΥåѡåפ줿δؿ
   ؾˡ롣Scale饤֥δˤȤơγݤ˼
   Ȥ˼٤ưϰʲΤɤ餫Ǥȹͤ롣</p>

   <ul>
     <li>ץλ</li>
     <li>Ƽ</li>
   </ul>

   <p>⤷ʤΥץबԤˤȤΤʤСⵤˤ
   s_mallocƤӽФƤɤγݤ˼ԤȤϼưŪexit()
   Ƥ֡ԤˤʤСֲǤץϥɥ
   ؿʰʲꥨ顼ϥɥˤs_merror_handler()˥åȤɬפ
   롣ꥨ顼ϥɥ餬ԤʤʤФʤʤȤϰʲ̤</p>

   <ol>
     <li></li>
     <li>true򡢽ʤfalse֤</li>
   </ol>

   <p>⤷⡢褺false֤ȥץ¸³ԲǽȤơϤ
   exit()ƤФ뤬true֤ХκƼԤʤȤ
   ꥨ顼ϥɥ餬餫Υtrue֤Ƥ⡢ޤ
   ݤ꤬­ʤȤ奨⤢롣Τ褦
   ȤϷ֤ߤ꤬ݤǤޤǡ˥ꥨ顼ϥɥ
   Ƥ³롣</p>

   <p>Scale󶡤ɸˤ̵ؿġҤȤĤϡs_realocn()
   s_freen()ȤäǸ`n'դؿ⤦ҤȤĤs_creallocn()
   s_cfreen()Ȥäǽ`c'դؿԤϡɽεǽȤƤ
   `n'դʤΤƱScaleΥѥMEMORY_DEBUG
   ȥγݡϿ褦ˤʤ롣ˤꡢ
   ˺ʥ꡼ˤ򸫤Ĥ뤳ȤǽˤʤΤǡScale饤֥
   ǤϾ`n'դƤ֡Ԥϡ¸εǽɲäƥ򥯥ꥢ
   롣s_creallocn()ϳĥΰ`Τ'򥯥ꥢȤ
   ꤬ݻǡϾäʤs_cfreen()ϥ򥯥ꥢƤ
   Τǡѥɤ䵡̩Ȥǡפ
   ळȤɤ</p>
*/

#ifndef _SCALE_ALLOC_H_
#define _SCALE_ALLOC_H_

#include <scale/commons.h>


/** ꡦ顼ϥɥ */
typedef sboolean (*merror_handler)();


#define typed_malloc(type) array_malloc(type, 1)
#define typed_calloc(type) array_calloc(type, 1)
#define array_malloc(type, num) (type *)s_malloc(sizeof(type) * num)
#define array_calloc(type, num) (type *)s_calloc(num, sizeof(type))


/** ꡦ顼ϥɥ򥻥åȤ롣 */
void			s_merror_handler(merror_handler);

/** ݤ */
spointer		s_malloc(size_t);

/** ݤΤ0ǽ롣 */
spointer		s_calloc(size_t, size_t);

/** ĥ롣 */
spointer		s_realloc(spointer p, size_t n);

/** Υꥵꤷơoldn˥ĥ롣 */
spointer		s_reallocn(spointer p, size_t oldn, size_t newn);

/** ưs_reallocnƱ˳ݤ0ǽ롣
	oldn >= newnǤȤs_reallocnȤޤäƱǤ롣*/
spointer		s_creallocn(spointer p, size_t oldn, size_t newn);

/** 롣 */
void			s_free(spointer p);

/** ꥵꤷƲ */
void			s_freen(spointer p, size_t n);

/** s_freen()ƱpΤ0ǽ롣 */
void			s_cfreen(spointer p, size_t n);

/** Scale饤֥ΥѥMEMORY_DEBUGƤС
	߳ݤƤ礭֤
	scale/alloc.hƤϢΥϢؿ
	̤ƵϿΤǡľmallocreallocѤϵϿʤ

	ѥMEMORY_DEBUGƤʤäȤϾ0֤ */
size_t			get_total_memory(void);

#endif /* _SCALE_ALLOC_H_ */
